// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

#ifndef __POSIX_RLIMIT_HPP__
#define __POSIX_RLIMIT_HPP__

#include <stout/nothing.hpp>
#include <stout/try.hpp>

#include <mesos/mesos.hpp>

namespace mesos {
namespace internal {
namespace rlimits {

// Convert from Mesos RLimit types to system
// resources (see e.g., `sys/resource.h`).
Try<int> convert(RLimitInfo::RLimit::Type type);


// Set the given resource limit for the calling process.
Try<Nothing> set(const RLimitInfo::RLimit& limit);

// Get the given resource limit for the calling process.
Try<RLimitInfo::RLimit> get(RLimitInfo::RLimit::Type type);

} // namespace rlimits {
} // namespace internal {
} // namespace mesos {

#endif // __POSIX_RLIMIT_HPP__
